@@ -356,7 +356,8 @@ def test_versioned_component_long_help():
         "                                  command\n"
         "  --install-dir DIR               Directory in which to unpack the `*.deb`\n"
         "  -m, --method [auto|apt|brew|neurodebian|deb-url|autobuild|snapshot|"
-        "conda|datalad/git-annex:tested|datalad/git-annex|datalad/packages|dmg]\n"
+        "conda|datalad/git-annex:tested|datalad/git-annex|"
+        "datalad/git-annex:release|datalad/packages|dmg]\n"
         "                                  Select the installation method to use\n"
         "  --path PATH                     Path to local `*.dmg` to install\n"
         "  --url URL                       URL from which to download `*.deb` file\n"
